@@ -141,7 +141,7 @@ sub load_policy_file {
     my $new = decode_json read_file $filename;
     if ($new) {
         $policy = $merger->merge( $policy, $new );
-        push @{$self->pfiles}, $filename;
+        push @{$self->pfiles}, $filename if (ref($self) and $self->isa(__PACKAGE__));
     }
 
     return !!$new;
@@ -420,7 +420,7 @@ This would set the level to C<INFO> for any C<SYSTEM:FILTER_THIS> messages that
 
 __DATA__
 {
-   "asnroots" : [ "asnlookup.zonemaster.net", "asnlookup.iis.se", "asn.cymru,com"],
+   "asnroots" : [ "asnlookup.zonemaster.net", "asnlookup.iis.se"],
    "net" : {
       "ipv4" : 1,
       "ipv6" : 1
@@ -438,4 +438,4 @@ __DATA__
          "usevc" : 0
       }
    }
-}
\ No newline at end of file
+}
