@@ -13,6 +13,9 @@ sub string {
     return $self->message;
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 =head1 NAME
